@@ -39,6 +39,8 @@ static bool_T __MyTreeCB(fsdbTreeCBType cb_type, void *client_data, void *tree_c
 
 extern "C" void *fsdbReaderOpenFile(char *nam)
 {
+fsdbFileType ft;
+
 if(!ffrObject::ffrIsFSDB(nam))
 	{
 	return(NULL);
@@ -46,7 +48,7 @@ if(!ffrObject::ffrIsFSDB(nam))
 
 ffrFSDBInfo fsdb_info;
 ffrObject::ffrGetFSDBInfo(nam, fsdb_info);
-if(fsdb_info.file_type != FSDB_FT_VERILOG)
+if((fsdb_info.file_type != FSDB_FT_VERILOG) && (fsdb_info.file_type != FSDB_FT_VERILOG_VHDL) && (fsdb_info.file_type != FSDB_FT_VHDL))
 	{
 	return(NULL);
 	}
@@ -59,7 +61,8 @@ if(!fsdb_obj)
 
 fsdb_obj->ffrSetTreeCBFunc(__TreeCB, NULL);
     
-if(fsdb_obj->ffrGetFileType() != FSDB_FT_VERILOG)
+ft = fsdb_obj->ffrGetFileType();
+if((ft != FSDB_FT_VERILOG) && (ft != FSDB_FT_VERILOG_VHDL) && (ft != FSDB_FT_VHDL))
 	{
         fsdb_obj->ffrClose();
 	return(NULL);
@@ -414,6 +417,42 @@ switch (scope->type)
 		type = (str_T) "sv_interface"; 
 		break;
 
+	case FSDB_ST_VHDL_ARCHITECTURE:
+		type = (str_T) "vhdl_architecture";
+		break;
+
+	case FSDB_ST_VHDL_PROCEDURE:
+		type = (str_T) "vhdl_procedure";
+		break;
+
+	case FSDB_ST_VHDL_FUNCTION:
+		type = (str_T) "vhdl_function";
+		break;
+
+	case FSDB_ST_VHDL_RECORD:
+		type = (str_T) "vhdl_record";
+		break;
+
+	case FSDB_ST_VHDL_PROCESS:
+		type = (str_T) "vhdl_process";
+		break;
+
+	case FSDB_ST_VHDL_BLOCK:
+		type = (str_T) "vhdl_block";
+		break;
+
+	case FSDB_ST_VHDL_FOR_GENERATE:
+		type = (str_T) "vhdl_for_generate";
+		break;
+
+	case FSDB_ST_VHDL_IF_GENERATE:
+		type = (str_T) "vhdl_if_generate";
+		break;
+
+	case FSDB_ST_VHDL_GENERATE:
+		type = (str_T) "vhdl_generate";
+		break;
+
 	default:
 		type = (str_T) "unknown_scope_type";
 		break;
@@ -577,6 +616,36 @@ switch (var->type)
     	case FSDB_VT_VHDL_MEMORY:
     	case FSDB_VT_VCD_MEMORY_DEPTH:
     	case FSDB_VT_VHDL_MEMORY_DEPTH:         
+		switch(var->vc_dt)
+			{
+			case FSDB_VC_DT_FLOAT:
+			case FSDB_VC_DT_DOUBLE:
+				type = (str_T) "vcd_real";
+				typelen = 8;
+				break;
+
+			case FSDB_VC_DT_UNKNOWN:
+			case FSDB_VC_DT_BYTE:
+			case FSDB_VC_DT_SHORT:
+			case FSDB_VC_DT_INT:
+			case FSDB_VC_DT_LONG:
+			case FSDB_VC_DT_HL_INT:
+			case FSDB_VC_DT_PHYSICAL:
+			default:
+				if(var->type == FSDB_VT_VHDL_SIGNAL)
+					{
+					type = (str_T) "vcd_wire";
+					typelen = 8;
+					}
+				else
+					{
+					type = (str_T) "vcd_reg";
+					typelen = 7;
+					}
+				break;
+			}
+		break;
+
     	default:
 		type = (str_T) "vcd_wire";
 		typelen = 8;
