@@ -53,7 +53,8 @@ enum fstBlockType {
 };
 
 enum fstScopeType {
-    FST_ST_VCD_MIN             = 0,
+    FST_ST_MIN                 = 0,
+
     FST_ST_VCD_MODULE          = 0,
     FST_ST_VCD_TASK            = 1,
     FST_ST_VCD_FUNCTION        = 2,
@@ -66,9 +67,18 @@ enum fstScopeType {
     FST_ST_VCD_INTERFACE       = 9,
     FST_ST_VCD_PACKAGE         = 10,
     FST_ST_VCD_PROGRAM         = 11,
-    FST_ST_VCD_MAX             = 11,
 
-    FST_ST_MAX                 = 11,
+    FST_ST_VHDL_ARCHITECTURE   = 12,
+    FST_ST_VHDL_PROCEDURE      = 13,
+    FST_ST_VHDL_FUNCTION       = 14,
+    FST_ST_VHDL_RECORD         = 15,
+    FST_ST_VHDL_PROCESS        = 16,
+    FST_ST_VHDL_BLOCK          = 17,
+    FST_ST_VHDL_FOR_GENERATE   = 18,
+    FST_ST_VHDL_IF_GENERATE    = 19,
+    FST_ST_VHDL_GENERATE       = 20,
+
+    FST_ST_MAX                 = 20,
 
     FST_ST_GEN_ATTRBEGIN       = 252,
     FST_ST_GEN_ATTREND         = 253,
@@ -78,7 +88,8 @@ enum fstScopeType {
 };
 
 enum fstVarType {
-    FST_VT_VCD_MIN             = 0,	/* start of VCD datatypes */
+    FST_VT_MIN                 = 0,	/* start of vartypes */
+
     FST_VT_VCD_EVENT           = 0,
     FST_VT_VCD_INTEGER         = 1,
     FST_VT_VCD_PARAMETER       = 2,
@@ -112,19 +123,25 @@ enum fstVarType {
     FST_VT_SV_ENUM             = 28,	/* declare as appropriate type range */
     FST_VT_SV_SHORTREAL        = 29,	/* declare and emit same as FST_VT_VCD_REAL */
 
-    FST_VT_VCD_MAX             = 29	/* end of VCD datatypes */
+    FST_VT_MAX                 = 29	/* end of vartypes */
 };
 
 enum fstVarDir {
+    FST_VD_MIN         = 0,
+
     FST_VD_IMPLICIT    = 0,
     FST_VD_INPUT       = 1,
     FST_VD_OUTPUT      = 2,
     FST_VD_INOUT       = 3,
+    FST_VD_BUFFER      = 4,
+    FST_VD_LINKAGE     = 5,
 
-    FST_VD_MAX         = 3
+    FST_VD_MAX         = 5
 };
 
 enum fstHierType {
+    FST_HT_MIN         = 0,
+
     FST_HT_SCOPE       = 0,
     FST_HT_UPSCOPE     = 1,
     FST_HT_VAR         = 2,
@@ -135,6 +152,8 @@ enum fstHierType {
 };
 
 enum fstAttrType {
+    FST_AT_MIN         = 0,
+
     FST_AT_MISC        = 0,
     FST_AT_ARRAY       = 1,
     FST_AT_ENUM        = 2,
@@ -144,13 +163,19 @@ enum fstAttrType {
 };
 
 enum fstMiscType {
-    FST_MT_COMMENT     = 0,	/* self-contained: does not need matching FST_HT_ATTREND, use fstWriterSetComment() to emit */
-    FST_MT_UNKNOWN     = 1,
+    FST_MT_MIN         = 0,
 
-    FST_MT_MAX         = 1
+    FST_MT_COMMENT     = 0,	/* self-contained: does not need matching FST_HT_ATTREND, use fstWriterSetComment() to emit */
+    FST_MT_ENVVAR      = 1,	/* self-contained: does not need matching FST_HT_ATTREND, use fstWriterSetEnvVar() to emit */
+    FST_MT_SUPVAR      = 2,
+    FST_MT_UNKNOWN     = 3,
+
+    FST_MT_MAX         = 3
 };
 
 enum fstArrayType {
+    FST_AR_MIN         = 0,
+
     FST_AR_NONE        = 0,
     FST_AR_UNPACKED    = 1,
     FST_AR_PACKED      = 2,
@@ -184,9 +209,52 @@ enum fstPackType {
     FST_PT_PACKED        = 2,
     FST_PT_TAGGED_PACKED = 3,
 
-    FST_PT_MAX           = 6
+    FST_PT_MAX           = 3
 };
 
+enum fstSupplimentalVarType {
+    FST_SVT_MIN                    = 0,
+
+    FST_SVT_NONE                   = 0,
+
+    FST_SVT_VHDL_SIGNAL            = 1,
+    FST_SVT_VHDL_VARIABLE          = 2,
+    FST_SVT_VHDL_CONSTANT          = 3,
+    FST_SVT_VHDL_FILE              = 4,
+    FST_SVT_VHDL_MEMORY            = 5,
+
+    FST_SVT_MAX                    = 5,
+};
+
+enum fstSupplimentalDataType {
+    FST_SDT_MIN                    = 0,
+
+    FST_SDT_NONE                   = 0,
+
+    FST_SDT_VHDL_BOOLEAN           = 1,
+    FST_SDT_VHDL_BIT               = 2,
+    FST_SDT_VHDL_BIT_VECTOR        = 3,
+    FST_SDT_VHDL_STD_ULOGIC        = 4,
+    FST_SDT_VHDL_STD_ULOGIC_VECTOR = 5,
+    FST_SDT_VHDL_STD_LOGIC         = 6,
+    FST_SDT_VHDL_STD_LOGIC_VECTOR  = 7,
+    FST_SDT_VHDL_UNSIGNED          = 8,
+    FST_SDT_VHDL_SIGNED            = 9,
+    FST_SDT_VHDL_INTEGER           = 10,
+    FST_SDT_VHDL_REAL              = 11,
+    FST_SDT_VHDL_NATURAL           = 12,
+    FST_SDT_VHDL_POSITIVE          = 13,
+    FST_SDT_VHDL_TIME              = 14,
+    FST_SDT_VHDL_CHARACTER         = 15,
+    FST_SDT_VHDL_STRING            = 16,
+
+    FST_SDT_MAX                    = 16,
+
+    FST_SDT_SVT_SHIFT_COUNT        = 10, /* FST_SVT_* is ORed in to the left after shifting FST_SDT_SVT_SHIFT_COUNT */
+    FST_SDT_ABS_MAX		   = (1<<(FST_SDT_SVT_SHIFT_COUNT))
+};
+
+
 struct fstHier
 {
 unsigned char htyp;
@@ -194,7 +262,7 @@ unsigned char htyp;
 union {
 	/* if htyp == FST_HT_SCOPE */
 	struct fstHierScope {
-		unsigned char typ; /* FST_ST_VCD_MODULE ... FST_ST_VCD_PROGRAM */
+		unsigned char typ; /* FST_ST_MIN ... FST_ST_MAX */
 		const char *name;
 		const char *component;
 		uint32_t name_length;		/* strlen(u.scope.name) */
@@ -203,8 +271,12 @@ union {
 
 	/* if htyp == FST_HT_VAR */
 	struct fstHierVar {
-		unsigned char typ; /* FST_VT_VCD_EVENT ... FST_VT_GEN_STRING */
-		unsigned char direction; /* FST_VD_IMPLICIT ... FST_VD_INOUT */
+		unsigned char typ; /* FST_VT_MIN ... FST_VT_MAX */
+		unsigned char direction; /* FST_VD_MIN ... FST_VD_MAX */
+
+		unsigned char svt_workspace; /* zeroed out by FST reader, for client code use */
+		unsigned char sdt_workspace; /* zeroed out by FST reader, for client code use */
+
 		const char *name;
 		uint32_t length;
 		fstHandle handle;
@@ -214,8 +286,8 @@ union {
 
 	/* if htyp == FST_HT_ATTRBEGIN */
 	struct fstHierAttr {
-		unsigned char typ; /* FST_AT_MISC ... FST_AT_PACK */
-		unsigned char subtype; /* from fstArrayType, fstEnumValueType, fstPackType */
+		unsigned char typ; /* FST_AT_MIN ... FST_AT_MAX */
+		unsigned char subtype; /* from fstMiscType, fstArrayType, fstEnumValueType, fstPackType */
 		const char *name;
 		uint64_t arg; /* number of array elements, struct members, or some other payload (possibly ignored) */
 		uint32_t name_length; /* strlen(u.attr.name) */
@@ -227,9 +299,17 @@ union {
 /*
  * writer functions
  */
+
+/* used for Verilog/SV */
 fstHandle fstWriterCreateVar(void *ctx, enum fstVarType vt, enum fstVarDir vd,
         uint32_t len, const char *nam, fstHandle aliasHandle);
 
+/* future expansion for VHDL and other languages.  The variable type, data type, etc map onto
+   the current Verilog/SV one.  The "type" string is optional for a more verbose or custom description */
+fstHandle fstWriterCreateVar2(void *ctx, enum fstVarType vt, enum fstVarDir vd,
+        uint32_t len, const char *nam, fstHandle aliasHandle,
+	const char *type, enum fstSupplimentalVarType svt, enum fstSupplimentalDataType sdt);
+
 void fstWriterSetPackType(void *ctx, int typ); 		/* type = 0 (libz), 1 (fastlz) */
 void fstWriterSetRepackOnClose(void *ctx, int enable); 	/* type = 0 (none), 1 (libz) */
 void fstWriterSetParallelMode(void *ctx, int enable);
@@ -242,6 +322,7 @@ void fstWriterClose(void *ctx);
 void fstWriterSetDate(void *ctx, const char *dat);
 void fstWriterSetVersion(void *ctx, const char *vers);
 void fstWriterSetComment(void *ctx, const char *comm);
+void fstWriterSetEnvVar(void *ctx, const char *envvar);
 void fstWriterSetTimescale(void *ctx, int ts);
 void fstWriterSetTimescaleFromString(void *ctx, const char *s);
 void fstWriterSetTimezero(void *ctx, int64_t tim);
