@@ -201,6 +201,21 @@ for(;;)
 					default:	break;
 					}
 				}
+                        else             
+                        if(!strncmp(vht, "vhdl_", 5))
+                                {
+                                switch(vht[5])   
+                                        {                
+                                        case 'a':       mtype = FST_ST_VHDL_ARCHITECTURE; break;
+                                        case 'r':       mtype = FST_ST_VHDL_RECORD; break;
+                                        case 'b':       mtype = FST_ST_VHDL_BLOCK; break;
+                                        case 'g':       mtype = FST_ST_VHDL_GENERATE; break;
+                                        case 'i':       mtype = FST_ST_VHDL_IF_GENERATE; break;  
+                                        case 'f':       mtype = (vht[6] == 'u') ? FST_ST_VHDL_FUNCTION : FST_ST_VHDL_FOR_GENERATE; break;
+                                        case 'p':       mtype = (!strncmp(vht+6, "roces", 5)) ? FST_ST_VHDL_PROCESS: FST_ST_VHDL_PROCEDURE; break;
+                                        default:        break;
+                                        }
+                                }
 
 			ctype[0] = mtype + 1; /* bias for zero terminated string */
 
@@ -325,12 +340,23 @@ char *fgets_rc;
 
 if(!*wbuf)
 	{
-	*wbuf = malloc(32768);
 	*len = 32767;
+	*wbuf = malloc((*len) + 1);
+	(*wbuf)[*len] = 1;
 	}
 
 (*wbuf)[0] = 0;
-fgets_rc = fgets(*wbuf, 32767, f);
+fgets_rc = fgets(*wbuf, (*len) + 1, f);
+while(((*wbuf)[*len] != 1) && !feof(f))
+	{
+	/* fprintf(stderr, "overflow %d\n", (int)(*len)); */
+	*wbuf = realloc(*wbuf, (*len) * 2 + 1);
+	(*wbuf)[(*len) * 2] = 1;
+
+	fgets_rc = fgets(*wbuf + (*len), (*len) + 1, f);	
+	*len = 2 * (*len);
+	}
+
 *buf = *wbuf;
 while(*(buf)[0]==' ') { (*buf)++; } /* verilator leading spaces fix */
 
@@ -378,14 +404,15 @@ int fst_main(char *vname, char *fstname)
 {
 FILE *f;
 char *buf = NULL, *wbuf = NULL;
-size_t glen;
+size_t glen = 0;
 void *ctx;
 int line = 0;
 size_t ss;
 fstHandle returnedhandle;
 JRB node;
 uint64_t prev_tim = 0;
-char bin_fixbuff[32769];
+size_t bin_fixbuff_len = 65537;
+char *bin_fixbuff = NULL;
 int hash_kill = 0;
 unsigned int hash_max = 0;
 int *node_len_array = NULL;
@@ -395,6 +422,8 @@ int is_extload = 0;
 void *xc = NULL;
 #endif
 
+bin_fixbuff = malloc(bin_fixbuff_len);
+
 if(!strcmp("-", vname))
 	{
 	f = stdin;
@@ -434,6 +463,7 @@ if(!strcmp("-", vname))
 if(!f)
 	{
 	printf("could not open '%s', exiting.\n", vname);
+	free(bin_fixbuff); bin_fixbuff = NULL;
 	exit(255);
 	}
 
@@ -442,6 +472,7 @@ ctx = fstWriterCreate(fstname, 1);
 if(!ctx)
 	{
 	printf("could not open '%s', exiting.\n", fstname);
+	free(bin_fixbuff); bin_fixbuff = NULL;
 	exit(255);
 	}
 
@@ -716,70 +747,138 @@ while(!feof(f))
 	if(!strncmp(buf, "$scope", 6))
 		{
 		char *st = strtok(buf+6, " \t");
-		enum fstScopeType scopetype;
+		enum fstScopeType scopetype = FST_ST_VCD_MODULE;
 
-		if(!strcmp(st, "module"))
+		switch(st[0])
 			{
-			scopetype = FST_ST_VCD_MODULE;
-			}
-		else
-		if(!strcmp(st, "task"))
-			{
-			scopetype = FST_ST_VCD_TASK;
-			}
-		else
-		if(!strcmp(st, "function"))
-			{
-			scopetype = FST_ST_VCD_FUNCTION;
-			}
-		else
-		if(!strcmp(st, "begin"))
-			{
-			scopetype = FST_ST_VCD_BEGIN;
-			}
-		else
-		if(!strcmp(st, "fork"))
-			{
-			scopetype = FST_ST_VCD_FORK;
-			}
-		else
-		if(!strcmp(st, "generate"))
-			{
-			scopetype = FST_ST_VCD_GENERATE;
-			}
-		else
-		if(!strcmp(st, "struct"))
-			{
-			scopetype = FST_ST_VCD_STRUCT;
-			}
-		else
-		if(!strcmp(st, "union"))
-			{
-			scopetype = FST_ST_VCD_UNION;
-			}
-		else
-		if(!strcmp(st, "class"))
-			{
-			scopetype = FST_ST_VCD_CLASS;
-			}
-		else
-		if(!strcmp(st, "interface"))
-			{
-			scopetype = FST_ST_VCD_INTERFACE;
-			}
-		else
-		if(!strcmp(st, "package"))
-			{
-			scopetype = FST_ST_VCD_PACKAGE;
-			}
-		else
-		if(!strcmp(st, "program"))
-			{
-			scopetype = FST_ST_VCD_PROGRAM;
-			}
-		else
-			{
-			scopetype = FST_ST_VCD_MODULE;
+			case 'm':
+				if(!strcmp(st, "module"))
+					{
+					}
+				break;
+
+			case 't':
+				if(!strcmp(st, "task"))
+					{
+					scopetype = FST_ST_VCD_TASK;
+					}
+				break;
+
+			case 'f':
+				if(!strcmp(st, "function"))
+					{
+					scopetype = FST_ST_VCD_FUNCTION;
+					}
+				else
+				if(!strcmp(st, "fork"))
+					{
+					scopetype = FST_ST_VCD_FORK;
+					}
+				break;
+
+			case 'b':
+				if(!strcmp(st, "begin"))
+					{
+					scopetype = FST_ST_VCD_BEGIN;
+					}
+				break;
+
+			case 'g':
+				if(!strcmp(st, "generate"))
+					{
+					scopetype = FST_ST_VCD_GENERATE;
+					}
+				break;
+
+			case 's':
+				if(!strcmp(st, "struct"))
+					{
+					scopetype = FST_ST_VCD_STRUCT;
+					}
+				break;
+
+			case 'u':
+				if(!strcmp(st, "union"))
+					{
+					scopetype = FST_ST_VCD_UNION;
+					}
+				break;
+
+			case 'c':
+				if(!strcmp(st, "class"))
+					{
+					scopetype = FST_ST_VCD_CLASS;
+					}
+				break;
+
+			case 'i':
+				if(!strcmp(st, "interface"))
+					{
+					scopetype = FST_ST_VCD_INTERFACE;
+					}
+				break;
+
+			case 'p':
+				if(!strcmp(st, "package"))
+					{
+					scopetype = FST_ST_VCD_PACKAGE;
+					}
+				else
+				if(!strcmp(st, "program"))
+					{
+					scopetype = FST_ST_VCD_PROGRAM;
+					}
+				break;
+
+			case 'v':
+				if(!strcmp(st, "vhdl_architecture"))
+					{
+					scopetype = FST_ST_VHDL_ARCHITECTURE;
+					}
+				else
+				if(!strcmp(st, "vhdl_procedure"))
+					{
+					scopetype = FST_ST_VHDL_PROCEDURE;
+					}
+				else
+				if(!strcmp(st, "vhdl_function"))
+					{
+					scopetype = FST_ST_VHDL_FUNCTION;
+					}
+				else
+				if(!strcmp(st, "vhdl_record"))
+					{
+					scopetype = FST_ST_VHDL_RECORD;
+					}
+				else
+				if(!strcmp(st, "vhdl_process"))
+					{
+					scopetype = FST_ST_VHDL_PROCESS;
+					}
+				else
+				if(!strcmp(st, "vhdl_block"))
+					{
+					scopetype = FST_ST_VHDL_BLOCK;
+					}
+				else
+				if(!strcmp(st, "vhdl_for_generate"))
+					{
+					scopetype = FST_ST_VHDL_FOR_GENERATE;
+					}
+				else
+				if(!strcmp(st, "vhdl_if_generate"))
+					{
+					scopetype = FST_ST_VHDL_IF_GENERATE;
+					}
+				else
+				if(!strcmp(st, "vhdl_generate"))
+					{
+					scopetype = FST_ST_VHDL_GENERATE;
+					}
+				break;
+
+			default:
+				break;
 			}
 
 		st = strtok(NULL, " \t");
@@ -1092,11 +1191,10 @@ while(!feof(f))
 	{
 	unsigned int hash;
 	uint64_t tim;
-	size_t len;
 	char *nl, *sp;
 	double doub;
 
-	ss = getline_replace(&wbuf, &buf, &len, f);
+	ss = getline_replace(&wbuf, &buf, &glen, f);
 	if(ss == -1)
 		{
 		break;
@@ -1147,13 +1245,20 @@ while(!feof(f))
 				int bin_len = sp - (buf + 1); /* strlen(buf+1) */
 				int node_len = node_len_array[hash];
 
-				if(bin_len == node_len)
+				if(bin_len >= node_len)
 					{
 					fstWriterEmitValueChange(ctx, hash, buf+1);
 					}
 					else
 					{
 					int delta = node_len - bin_len;
+
+					if(node_len >= bin_fixbuff_len)
+						{
+						bin_fixbuff_len = node_len + 1;
+						bin_fixbuff = realloc(bin_fixbuff, bin_fixbuff_len);
+						}
+
 					memset(bin_fixbuff, buf[1] != '1' ? buf[1] : '0', delta);
 					memcpy(bin_fixbuff + delta, buf+1, bin_len);
 					fstWriterEmitValueChange(ctx, hash, bin_fixbuff);
@@ -1166,13 +1271,20 @@ while(!feof(f))
 					{
 					int bin_len = sp - (buf + 1); /* strlen(buf+1) */
 					int node_len = node->val2.i;
-					if(bin_len == node_len)
+					if(bin_len >= node_len)
 						{
 						fstWriterEmitValueChange(ctx, node->val.i, buf+1);
 						}
 						else
 						{
 						int delta = node_len - bin_len;
+
+						if(node_len >= bin_fixbuff_len)
+							{
+							bin_fixbuff_len = node_len + 1;
+							bin_fixbuff = realloc(bin_fixbuff, bin_fixbuff_len);
+							}
+
 						memset(bin_fixbuff, buf[1] != '1' ? buf[1] : '0', delta);
 						memcpy(bin_fixbuff + delta, buf+1, bin_len);
 						fstWriterEmitValueChange(ctx, node->val.i, bin_fixbuff);
@@ -1215,8 +1327,16 @@ while(!feof(f))
 		case 'p':
 			{
 			char *src = buf+1;
-			char *pnt = bin_fixbuff;
+			char *pnt;
 			int pchar = 0;
+			int p_len = strlen(src);
+
+			if(p_len >= bin_fixbuff_len)
+				{
+				bin_fixbuff_len = p_len + 1;
+				bin_fixbuff = realloc(bin_fixbuff, bin_fixbuff_len);
+				}
+			pnt = bin_fixbuff;
 
 			for(;;)
 				{
@@ -1351,6 +1471,7 @@ if(vcd_ids)
 	vcd_ids = NULL;
 	}
 
+free(bin_fixbuff); bin_fixbuff = NULL;
 free(wbuf); wbuf = NULL;
 free(node_len_array); node_len_array = NULL;
 
