@@ -42,7 +42,7 @@ enum { VIEW_DRAG_INACTIVE, TREE_TO_VIEW_DRAG_ACTIVE, SEARCH_TO_VIEW_DRAG_ACTIVE
 /* The signal area is based on a tree view which requires a store model.
    This store model contains the list of signals to be displayed.
 */
-enum { NAME_COLUMN, TREE_COLUMN, TYPE_COLUMN, DIR_COLUMN, N_COLUMNS };
+enum { NAME_COLUMN, TREE_COLUMN, TYPE_COLUMN, DIR_COLUMN, DTYPE_COLUMN, N_COLUMNS };
 
 /* list of autocoalesced (synthesized) filter names that need to be freed at some point) */
 
@@ -134,6 +134,8 @@ fill_sig_store (void)
 	int vartype;
 	int vardir;
 	int is_tname = 0;
+	int wrexm;
+	int vardt;
 
 	if(i < 0) continue;
 
@@ -149,6 +151,12 @@ fill_sig_store (void)
 		vardir = 0;
 		}
 
+	vardt = GLOBALS->facs[i]->n->vardt;
+	if((vardt < 0) || (vardt > ND_VDT_MAX))
+		{
+		vardt = 0;
+		}
+
         if(!GLOBALS->facs[i]->vec_root)
 		{
 		is_tname = 1;
@@ -180,7 +188,11 @@ fill_sig_store (void)
                         }
                 }
 
-	if (GLOBALS->filter_str_treesearch_gtk2_c_1 == NULL || wave_regex_match(t->name, WAVE_REGEX_TREE))
+	if 	(
+		(GLOBALS->filter_str_treesearch_gtk2_c_1 == NULL) || 
+		((!GLOBALS->filter_noregex_treesearch_gtk2_c_1) && (wrexm = wave_regex_match(t->name, WAVE_REGEX_TREE)) && (!GLOBALS->filter_matlen_treesearch_gtk2_c_1)) ||
+		(GLOBALS->filter_matlen_treesearch_gtk2_c_1 && (GLOBALS->filter_typ_treesearch_gtk2_c_1 == vardir) && wrexm)
+		)
       		{
 		gtk_list_store_prepend (GLOBALS->sig_store_treesearch_gtk2_c_1, &iter);
 		if(is_tname)
@@ -189,7 +201,8 @@ fill_sig_store (void)
 				    NAME_COLUMN, s,
 				    TREE_COLUMN, t,
 				    TYPE_COLUMN, vartype_strings[vartype],
-				    DIR_COLUMN,vardir_strings[vardir],
+				    DIR_COLUMN, vardir_strings[vardir],
+				    DTYPE_COLUMN, vardatatype_strings[vardt],
 				    -1);
 
 			if(s != t->name)
@@ -208,7 +221,8 @@ fill_sig_store (void)
 				    NAME_COLUMN, s,
 				    TREE_COLUMN, t,
 				    TYPE_COLUMN, vartype_strings[vartype],
-				    DIR_COLUMN,vardir_strings[vardir],
+				    DIR_COLUMN, vardir_strings[vardir],
+				    DTYPE_COLUMN, vardatatype_strings[vardt],
 				    -1);
 			}
       		}
@@ -635,9 +649,36 @@ gboolean filter_edit_cb (GtkWidget *widget, GdkEventKey *ev, gpointer *data)
 	GLOBALS->filter_str_treesearch_gtk2_c_1 = NULL;
       else
 	{
+	int i;
+
 	GLOBALS->filter_str_treesearch_gtk2_c_1 = malloc_2(strlen(t) + 1);
 	strcpy(GLOBALS->filter_str_treesearch_gtk2_c_1, t);
-	wave_regex_compile(GLOBALS->filter_str_treesearch_gtk2_c_1, WAVE_REGEX_TREE);
+
+	GLOBALS->filter_typ_treesearch_gtk2_c_1 = ND_DIR_UNSPECIFIED;
+	GLOBALS->filter_matlen_treesearch_gtk2_c_1 = 0;
+	GLOBALS->filter_noregex_treesearch_gtk2_c_1 = 0;
+
+	if(GLOBALS->filter_str_treesearch_gtk2_c_1[0] == '+')
+		{
+		for(i=0;i<=ND_DIR_MAX;i++)
+			{
+			int tlen = strlen(vardir_strings[i]);
+			if(!strncasecmp(vardir_strings[i], GLOBALS->filter_str_treesearch_gtk2_c_1 + 1, tlen))
+				{
+				if(GLOBALS->filter_str_treesearch_gtk2_c_1[tlen + 1] == '+')
+					{
+					GLOBALS->filter_matlen_treesearch_gtk2_c_1 = tlen + 2;
+					GLOBALS->filter_typ_treesearch_gtk2_c_1 = i;
+					if(GLOBALS->filter_str_treesearch_gtk2_c_1[tlen + 2] == 0)
+						{
+						GLOBALS->filter_noregex_treesearch_gtk2_c_1 = 1;
+						}
+					}
+				}			
+			}
+		}
+
+	wave_regex_compile(GLOBALS->filter_str_treesearch_gtk2_c_1 + GLOBALS->filter_matlen_treesearch_gtk2_c_1, WAVE_REGEX_TREE);
 	}
       fill_sig_store ();
     }
@@ -1392,11 +1433,19 @@ do_tooltips:
 		case VCD_FILE:
 		case VCD_RECODER_FILE:
 		case DUMPLESS_FILE:
-					column = gtk_tree_view_column_new_with_attributes ("Type",
+					column = gtk_tree_view_column_new_with_attributes (GLOBALS->supplemental_datatypes_encountered ? "VType" : "Type",
 							   renderer,
 							   "text", TYPE_COLUMN,
 							   NULL);
 					gtk_tree_view_append_column (GTK_TREE_VIEW (sig_view), column);
+					if(GLOBALS->supplemental_datatypes_encountered)
+						{
+						column = gtk_tree_view_column_new_with_attributes ("DType",
+							   renderer,
+							   "text", DTYPE_COLUMN,
+							   NULL);
+						gtk_tree_view_append_column (GTK_TREE_VIEW (sig_view), column);
+						}
 					break;
 		default:
 			 		break;
@@ -1458,22 +1507,18 @@ do_tooltips:
     if(!GLOBALS->do_dynamic_treefilter)
 	{
     	gtkwave_signal_connect(GTK_OBJECT (GLOBALS->filter_entry), "key_press_event", (GtkSignalFunc) filter_edit_cb, NULL);
-	gtk_tooltips_set_tip_2(tooltips, GLOBALS->filter_entry,
-			   "Add a POSIX filter. "
-			   "'.*' matches any number of characters,"
-			   " '.' matches any character.  Hit Return to apply.",
-			   NULL);
 	}
 	else
 	{
     	gtkwave_signal_connect(GTK_OBJECT(GLOBALS->filter_entry), "changed", GTK_SIGNAL_FUNC(press_callback), NULL);
-	gtk_tooltips_set_tip_2(tooltips, GLOBALS->filter_entry,
-			   "Add a POSIX filter. "
-			   "'.*' matches any number of characters,"
-			   " '.' matches any character.",
-			   NULL);
 	}
 
+    gtk_tooltips_set_tip_2(tooltips, GLOBALS->filter_entry,
+	   "Add a POSIX filter. "
+	   "'.*' matches any number of characters,"
+	   " '.' matches any character.  Hit Return to apply."
+	   " The filter may be preceded with the port direction if it exists such as +I+, +O+, +IO+, etc.",
+	   NULL);
 
     gtk_box_pack_start (GTK_BOX (filter_hbox), GLOBALS->filter_entry, FALSE, FALSE, 1);
 
@@ -1631,7 +1676,7 @@ GtkWidget* treeboxframe(char *title, GtkSignalFunc func)
 
 
     /* Signal names.  */
-    GLOBALS->sig_store_treesearch_gtk2_c_1 = gtk_list_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_STRING, G_TYPE_STRING);
+    GLOBALS->sig_store_treesearch_gtk2_c_1 = gtk_list_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
     GLOBALS->sig_root_treesearch_gtk2_c_1 = GLOBALS->treeroot;
     fill_sig_store ();
 
@@ -1667,11 +1712,19 @@ GtkWidget* treeboxframe(char *title, GtkSignalFunc func)
 		case VCD_FILE:
 		case VCD_RECODER_FILE:
 		case DUMPLESS_FILE:
-					column = gtk_tree_view_column_new_with_attributes ("Type",
+					column = gtk_tree_view_column_new_with_attributes (GLOBALS->supplemental_datatypes_encountered ? "VType" : "Type",
 							   renderer,
 							   "text", TYPE_COLUMN,
 							   NULL);
 					gtk_tree_view_append_column (GTK_TREE_VIEW (sig_view), column);
+					if(GLOBALS->supplemental_datatypes_encountered)
+						{
+						column = gtk_tree_view_column_new_with_attributes ("DType",
+							   renderer,
+							   "text", DTYPE_COLUMN,
+							   NULL);
+						gtk_tree_view_append_column (GTK_TREE_VIEW (sig_view), column);
+						}
 					break;
 		default:
 					break;
@@ -1727,22 +1780,19 @@ GtkWidget* treeboxframe(char *title, GtkSignalFunc func)
     if(!GLOBALS->do_dynamic_treefilter)
 	{
     	gtkwave_signal_connect(GTK_OBJECT (GLOBALS->filter_entry), "key_press_event", (GtkSignalFunc) filter_edit_cb, NULL);
-	gtk_tooltips_set_tip_2(tooltips, GLOBALS->filter_entry,
-			   "Add a POSIX filter. "
-			   "'.*' matches any number of characters,"
-			   " '.' matches any character.  Hit Return to apply.",
-			   NULL);
 	}
 	else
 	{
 	gtkwave_signal_connect(GTK_OBJECT(GLOBALS->filter_entry), "changed", GTK_SIGNAL_FUNC(press_callback), NULL);
-	gtk_tooltips_set_tip_2(tooltips, GLOBALS->filter_entry,
-			   "Add a POSIX filter. "
-			   "'.*' matches any number of characters,"
-			   " '.' matches any character.",
-			   NULL);
 	}
 
+    gtk_tooltips_set_tip_2(tooltips, GLOBALS->filter_entry,
+	   "Add a POSIX filter. "
+	   "'.*' matches any number of characters,"
+	   " '.' matches any character.  Hit Return to apply."
+	   " The filter may be preceded with the port direction if it exists such as +I+, +O+, +IO+, etc.",
+	   NULL);
+
     gtk_box_pack_start (GTK_BOX (filter_hbox), GLOBALS->filter_entry, FALSE, FALSE, 1);
 
     gtk_box_pack_start (GTK_BOX (vbox), filter_hbox, FALSE, FALSE, 1);
